@@ -27,9 +27,10 @@ def SmartFormatter(x):
 	- EngNumber(x) if x is a float
 	- A smart formatting if x is decorated with UnitInfo object
 	- str(x) in any other case
+	:-)
 	'''
 
-	if x is float:
+	if type(x) is float:
 		return EngNumber(x)
 	else:
 		return str(x)
